@@ -17,13 +17,17 @@ import json # To support export/import json files
 import yaml # To support export/import yaml files
 import os # To manage paths, folders and files
 from os import path # To check if file or folder exists in path
-import sys; sys.path.append(os.path.dirname(os.path.realpath(__file__))) # This code is from https://stackoverflow.com/questions/16981921/relative-imports-in-python-3/49375740#49375740
+import sys #; sys.path.append(os.path.dirname(os.path.realpath(__file__))) # This code is from https://stackoverflow.com/questions/16981921/relative-imports-in-python-3/49375740#49375740
 import warnings # To send warnings
 #import pypistats # To see PREFS library stats in pypi
 
 #Dependencies
-from readPREFS import ReadPREFS
-from createPREFS import CreatePREFS
+if __name__ == '__main__':
+	from readPREFS import ReadPREFS
+	from createPREFS import CreatePREFS
+else:
+	from .readPREFS import ReadPREFS
+	from .createPREFS import CreatePREFS
 
 class PREFS: 
 	"""PREFS class creates a file to store and manage user preferences.
